# filers2
Video tools for recording experiments.

For more information: http://matham.github.io/filers2/index.html

To install https://matham.github.io/filers2/installation.html


.. image:: https://github.com/matham/filers2/workflows/Python%20application/badge.svg
    :target: https://github.com/matham/filers2/actions
    :alt: Github action status
